You are viewing a plain text version of this content. The canonical link for it is here.
Posted to notifications@libcloud.apache.org by to...@apache.org on 2014/01/03 15:59:47 UTC

[35/44] git commit: Rename nodelist to node_list

Rename nodelist to node_list


Project: http://git-wip-us.apache.org/repos/asf/libcloud/repo
Commit: http://git-wip-us.apache.org/repos/asf/libcloud/commit/9e6caa75
Tree: http://git-wip-us.apache.org/repos/asf/libcloud/tree/9e6caa75
Diff: http://git-wip-us.apache.org/repos/asf/libcloud/diff/9e6caa75

Branch: refs/heads/trunk
Commit: 9e6caa7579e1874daf31fefbc8084915abd4b192
Parents: 4876970
Author: Rick Wright <ri...@google.com>
Authored: Mon Dec 30 08:48:58 2013 -0800
Committer: Rick Wright <ri...@google.com>
Committed: Thu Jan 2 23:30:03 2014 -0800

----------------------------------------------------------------------
 libcloud/compute/drivers/gce.py | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/libcloud/blob/9e6caa75/libcloud/compute/drivers/gce.py
----------------------------------------------------------------------
diff --git a/libcloud/compute/drivers/gce.py b/libcloud/compute/drivers/gce.py
index 5c569a4..71d2d1f 100644
--- a/libcloud/compute/drivers/gce.py
+++ b/libcloud/compute/drivers/gce.py
@@ -2322,14 +2322,14 @@ class GCENodeDriver(NodeDriver):
             node.extra['boot_disk'].destroy()
         return True
 
-    def ex_destroy_multiple_nodes(self, nodelist, ignore_errors=True,
+    def ex_destroy_multiple_nodes(self, node_list, ignore_errors=True,
                                   destroy_boot_disk=False, poll_interval=2,
                                   timeout=DEFAULT_TASK_COMPLETION_TIMEOUT):
         """
         Destroy multiple nodes at once.
 
         :param  nodelist: List of nodes to destroy
         :type   nodelist: ``list`` of :class:`Node`
 
         :keyword  ignore_errors: If true, don't raise an exception if one or
                                  more nodes fails to be destroyed.
@@ -2353,7 +2353,7 @@ class GCENodeDriver(NodeDriver):
         status_list = []
         complete = False
         start_time = time.time()
-        for node in nodelist:
+        for node in node_list:
             request = '/zones/%s/instances/%s' % (node.extra['zone'].name,
                                                   node.name)
             try:
@@ -2322,14 +2322,14 @@ class GCENodeDriver(NodeDriver):
         Destroy multiple nodes at once.
 
-        :param  nodelist: List of nodes to destroy
-        :type   nodelist: ``list`` of :class:`Node`
+        :param  node_list: List of nodes to destroy
+        :type   node_list: ``list`` of :class:`Node`
 
         :keyword  ignore_errors: If true, don't raise an exception if one or